pub struct OptionsPosition {Show 14 fields
pub symbol: String,
pub underlying_symbol: String,
pub is_long: bool,
pub unit_cost: Option<Rational64>,
pub unit_bid_price: Option<Rational64>,
pub unit_ask_price: Option<Rational64>,
pub unit_delta: Option<NotNan<f64>>,
pub unit_vega: Option<NotNan<f64>>,
pub unit_theta: Option<NotNan<f64>>,
pub quantity: Rational64,
pub strike_price: Rational64,
pub option_type: OptionType,
pub expiration_date: ExpirationDate,
pub lot_size: Option<i64>,
}Fields
symbol: StringThe symbol of the option itself.
underlying_symbol: StringThe symbol of the instrument that the option is a derivative of.
is_long: boolWhether the position is long or short the underlying.
unit_cost: Option<Rational64>The original cost per option contract in this position. If the position is long, this should be negative.
unit_bid_price: Option<Rational64>The current bid price per option contract in this position. If the position is long, this should be positive.
unit_ask_price: Option<Rational64>The current ask price per option contract in this position. If the position is long, this should be positive.
unit_delta: Option<NotNan<f64>>The delta per option contract in this position, where the delta equivalent of 1 share == 0.01.
unit_vega: Option<NotNan<f64>>The vega per option contract in this position.
unit_theta: Option<NotNan<f64>>The theta per option contract in this position.
quantity: Rational64The number of option contracts in this position.
strike_price: Rational64The strike price of the option.
option_type: OptionTypeThe type of the option.
expiration_date: ExpirationDateThe expiration date of the option.
lot_size: Option<i64>The number of units of the underlying per option contract in this position. Assumed to be 100 if not defined.
Implementations
Sourceimpl OptionsPosition
impl OptionsPosition
pub fn description(&self) -> String